Descargar T-Rex Miner

0.26.8
Kryptex Pool: Confiable. Eficiente. Rentable.

Minero T-Rex — Guía completa

-a, --algo                     Indica el algoritmo de hash que se usará.
                                   autolykos2
                                   blake3
                                   etchash
                                   ethash
                                   firopow
                                   kawpow
                                   mtp
                                   mtp-tcr
                                   multi
                                   octopus
                                   progpow
                                   progpow-veil
                                   progpow-veriblock
                                   progpowz
                                   tensority
        --coin                     Define el nombre de la moneda.
                                   Ayuda a evitar que se reconstruya el DAG al volver de una sesión de dev fee.
                                   Ejemplo: "etc" para Ethereum Classic, "etc+zil" para minar Ethereum Classic + Zilliqa.
        --extra-dag-epoch          Reserva en la GPU un DAG adicional para la época indicada. Puede ser útil en la minería dual
                                   de monedas como Zilliqa (ZIL). (p. ej.: --extra-dag-epoch 0)
                                   Se puede definir para cada GPU por separado con una lista de valores separados por comas
                                   (usa -1 para las GPUs que no deben reservar el DAG adicional).
        --nonce-start              [Ethash, ProgPOW] Nonce inicial para la búsqueda de soluciones.
        --nonce-range-size         [Ethash, ProgPOW] Tamaño del rango de nonces para la búsqueda. El rango se reparte entre todos los dispositivos.
    -d, --devices                  Lista separada por comas de los dispositivos CUDA que se usarán.
                                   Los ID de dispositivo se cuentan desde 0.
        --ab-indexing              Indexación de Afterburner (igual que la predeterminada, pero empieza en 1).
        --devices-info             Muestra la lista de dispositivos compatibles con CUDA disponibles en el sistema.
    -i, --intensity                Intensidad de la GPU 8-25 (por defecto: auto).
                                   Controla el tamaño de la carga de trabajo de la GPU, es decir, cuántos nonces procesa
                                   el minero "de una vez": N = 2 ^ intensity
        --low-load                 Modo de baja carga (por defecto: 0). 1 - activado, 0 - desactivado.
                                   Reduce la carga de las GPUs si es posible. Puede indicarse como lista separada por comas para activar
                                   el modo solo en algunas GPUs de la lista (p. ej.: --low-load 0,0,1,0)
        --dual-algo                Segundo algoritmo para el modo de minería dual.
        --dual-algo-mode           Controla el comportamiento de la GPU en el modo de minería dual (por defecto: a12).
                                   Formato: <algo>:<tuning coefficient>
                                   "<algo>" puede ser: "a1" (primer algoritmo), "a2" (segundo algoritmo), "a12" (ambos: minería dual)
                                   "<tuning coefficient>" es opcional y puede ser
                                         "rXX" (coeficiente "dual ratio" igual a XX), o
                                         "rXX:lrYY" (coeficiente "dual ratio" igual a XX, coeficiente "LHR dual ratio" igual a YY), o
                                         "hXX" (porcentaje XX del hashrate del algoritmo principal).
                                   Consulta la guía de minería dual para más detalles.
        --profit-per-mh            Rentabilidad estimada de los algoritmos en modo de minería dual por cada 1MH de hashrate.
                                   Sirve para ajustar la proporción algo1/algo2; el minero intentará maximizar las ganancias.
                                   Formato: <profit_algo1>:<profit_algo2>.
                                   Ejemplo: --profit-per-mh 0.0516:0.0012
        --lhr-tune                 [Ethash, Autolykos2] Valor de ajuste LHR que indica el porcentaje de la velocidad completa que el minero
                                   intenta alcanzar en tarjetas LHR (por defecto: -1). Rango de 10 a 95.
                                   -1 - automático
                                    0 - desactivado (úsalo en tarjetas que no son LHR)
                                   74 - valor inicial recomendado para la mayoría de las tarjetas LHR en modo de bajo consumo (ver --lhr-low-power)
                                   78 - valor inicial recomendado para la mayoría de las tarjetas LHR
                                   Se puede definir para cada GPU por separado, p. ej.
                                   "lhr-tune": "0,0,77.5,0" - esto fija el valor de ajuste LHR en 77.5 para la tercera GPU.
        --lhr-autotune-mode        [Ethash, Autolykos2] Modo de autoajuste LHR (por defecto: down). Valores válidos:
                                   off  - autoajuste desactivado. El valor de ajuste LHR queda fijo durante la minería y no cambia
                                          sin importar con qué frecuencia se detecte el bloqueo LHR
                                   down - el valor de ajuste LHR disminuye si el minero detecta un bloqueo LHR
                                   full - igual que "down", pero además el minero intentará aumentar el valor
                                          de ajuste LHR si es estable en el nivel actual
        --lhr-autotune-step-size   Tamaño del paso del autoajuste LHR (por defecto: 0.1).
                                   Indica cuánto cambia el autoajustador el valor de ajuste LHR en cada paso.
        --lhr-autotune-interval    Intervalo de tiempo del autoajuste LHR en minutos (por defecto: 5:120).
                                   Formato: <interval_up>:<interval_down>.
                                   "<interval_up>" es el tiempo en minutos que la GPU debe minar sin
                                   bloqueos LHR antes de que el minero intente aumentar el valor de ajuste LHR.
                                   Si la GPU activa el LHR, el valor de ajuste no disminuirá si el bloqueo LHR anterior
                                   se detectó hace más de "<interval_down>" minutos.
        --lhr-low-power            [Ethash] Reduce el consumo en modo LHR a cambio de un hashrate algo menor (por defecto: 0).
                                   1 - activado, 0 - desactivado. Puede indicarse como lista separada por comas para activar
                                   el modo solo en algunas GPUs (p. ej.: --lhr-low-power 0,0,1,0)
        --kernel                   [Ethash] Elige el kernel CUDA (por defecto: 0). Rango de 0 a 5.
                                   Usa 0 para activar el autoajuste: el minero hará un benchmark de cada kernel y elegirá el más rápido.
                                   Puede indicarse como lista separada por comas para aplicar valores distintos a cada tarjeta.
                                   (p. ej.: --kernel 2,1,1,3)
                                   Más adelante, el soporte de este parámetro podría ampliarse a otros algoritmos.
        --gpu-init-mode            Activa la inicialización secuencial del DAG (por defecto: 0).
                                   0 - todas las GPUs se inicializan en paralelo
                                   1 - inicialización totalmente secuencial, una GPU a la vez
                                   2 - dos GPUs a la vez
                                   etc.
        --dag-build-mode           [Ethash, ProgPOW, Octopus] Controla cómo se construye el DAG (por defecto: 0).
                                   0 - automático (el minero elige el modo más adecuado según el modelo de GPU)
                                   1 - predeterminado (adecuado para la mayoría de las tarjetas gráficas)
                                   2 - recomendado para tarjetas 30xx para evitar shares inválidos
                                   Puede indicarse como lista separada por comas para aplicar valores distintos a cada tarjeta.
                                   (p. ej.: --dag-build-mode 1,1,2,1)
        --dataset-mode             [Autolykos2] Modo del dataset. (por defecto: 2). Valores válidos:
                                   0 - automático (equivale a 2)
                                   1 - simple (en cada bloque de ERGO la GPU deja de calcular hashes hasta generar el dataset)
                                   2 - doble (el minero genera el dataset del siguiente bloque de ERGO antes de que llegue,
                                       con una pequeña penalización en el hashrate reportado, y cuando llega el bloque
                                       empieza a calcular hashes de inmediato sin perder 1-4 segundos creando el dataset).
                                       En este modo se duplica la memoria necesaria, ya que la GPU debe mantener dos búferes.
                                       Si la GPU no tiene memoria suficiente para dos datasets, el minero vuelve
                                       al modo de un solo búfer.
        --keep-gpu-busy            Sigue minando incluso si se pierde la conexión con el pool.
                                   Útil cuando una GPU falla durante el ciclo de arranque/parada que ocurre cuando se cae
                                   la conexión a internet.

    -o, --url                      URL del pool de minería con el siguiente formato: <scheme>://<host>:<port>
                                   Esquemas soportados: stratum+tcp
                                                      stratum+ssl
                                                      stratum+http
                                                      stratum2+tcp
                                                      stratum2+ssl
                                   stratum2 lo usan normalmente Nicehash, MiningPoolHub y otros pools similares
                                   Ejemplo: stratum+tcp://eu1.ethermine.org:4444
                                            stratum+ssl://zcoin.mintpond.com:3005
                                            stratum2+tcp://daggerhashimoto.hk.nicehash.com:3353
        --url2                     URL de un segundo pool, usado para el segundo algoritmo en modo de minería dual.
    -u, --user                     Nombre de usuario para el servidor de minería.
        --user2                    Nombre de usuario para el servidor de minería del segundo algoritmo en modo de minería dual.
    -p, --pass                     Contraseña para el servidor de minería.
        --pass2                    Contraseña para el servidor de minería del segundo algoritmo en modo de minería dual.
    -w, --worker                   Nombre del worker.
        --worker2                  Nombre del worker para el servidor de minería del segundo algoritmo en modo de minería dual.
        --proxy                    IP:puerto para conectarse a través de un servidor proxy SOCKS5.
                                   Los nombres de dominio también se resuelven a través del proxy.
        --dns-https-server         IP:puerto de un servidor DNS que funciona mediante DNS-over-HTTPS.
    -r, --retries                  Número de reintentos si falla una llamada de red.
    -R, --retry-pause              Pausa en segundos entre reintentos.
    -T, --timeout                  Tiempo de espera de red, en segundos (por defecto: 300)
        --time-limit               Intervalo tras el cual se apaga el minero, en segundos. (por defecto: 0 - desactivado)
        --temperature-color        Define el color de la temperatura del núcleo en las estadísticas de GPU. Ejemplo: 55,65 significa que
                                   las temperaturas por encima de 55 se muestran en amarillo y por encima de 65, en rojo. (por defecto: 67,77)
        --temperature-color-mem    Define el color de la temperatura de la memoria en las estadísticas de GPU. (por defecto: 80,100)
        --temperature-limit        Temperatura del núcleo a la que se detiene la GPU. (por defecto: 0 - desactivado)
        --temperature-start        Temperatura del núcleo a la que se reactiva la tarjeta tras detenerse. (por defecto: 0 - desactivado)
        --api-bind-http            IP:puerto de la API del minero por HTTP (por defecto: 127.0.0.1:4067). Usa 0 para desactivarla.
                                   Para acceso externo, usa la IP 0.0.0.0; en ese caso también se recomienda
                                   activar "--api-read-only".
        --api-https                Activa el protocolo https para las llamadas a la API.
        --api-key                  Clave de autorización generada previamente para las llamadas a la API. Usa "--api-generate-key" para generarla.
                                   Obligatoria para permitir llamadas a la API que modifican o actualizan datos.
        --api-read-only            Permite solo operaciones de lectura en las llamadas a la API.
                                   Activado por defecto si no se define "--api-key".
        --api-generate-key         Genera una clave de API a partir de una contraseña definida por el usuario. La clave resultante es el valor de "--api-key".
                                   Usa esta opción junto con "-c" para escribir api-key directamente en tu archivo de configuración.
        --api-webserver-cert       Ruta completa al archivo de certificado del servidor web de la API.
        --api-webserver-pkey       Ruta completa al archivo de clave privada del servidor web de la API.
    -N, --hashrate-avr             Duración en segundos de la ventana deslizante para calcular el hashrate promedio (por defecto: 60, máx.: 86400).
        --sharerate-avr            Duración en segundos de la ventana deslizante para calcular la tasa de shares (por defecto: 600).
        --gpu-report-interval      Frecuencia del informe de estadísticas de GPU. Mínimo 5 s. (por defecto: 30 s)
        --gpu-report-interval-s    Frecuencia del informe de estadísticas de GPU en shares. 0 por defecto (desactivado).
    -q, --quiet                    Modo silencioso. Sin ninguna estadística de GPU.
        --hide-date                No muestra la fecha en la consola.
        --send-stales              No descarta los shares obsoletos.
        --validate-shares          Valida los shares antes de enviarlos al pool. También muestra la dificultad de los shares.
        --no-color                 Desactiva los colores en la consola.
        --no-hashrate-report       Desactiva el envío del hashrate al pool.
        --no-new-block-info        No muestra en la consola la información de nuevos bloques.
        --no-nvml                  Desactiva las estadísticas de GPU vía NVML.
        --no-strict-ssl            Desactiva la validación de certificados en las conexiones SSL.
        --no-sni                   Desactiva el encabezado SNI en las conexiones SSL.
        --no-watchdog              Desactiva el watchdog integrado.
        --watchdog-exit-mode       Indica la acción "A" que debe tomar el watchdog si el minero se reinicia "N" veces
                                   en "M" minutos.
                                   Formato: N:M:A. Valores válidos:
                                                  N: cualquier entero positivo,
                                                  M: cualquier entero positivo,
                                                  A: r(reinicio del sistema), s(apagado del sistema), e(salida del minero)
                                   Las acciones "r" y "s" requieren ejecutar el minero con privilegios de administrador.
                                   Ejemplos:
                                   20:10:s - el watchdog apagará el sistema si el minero se reinicia 20 veces
                                             en cualquier intervalo de 10 minutos
                                   5:7:r   - el watchdog reiniciará el sistema si el minero se reinicia 5 veces
                                             en cualquier intervalo de 7 minutos
    -B, --benchmark                Modo benchmark.
        --benchmark-epoch          Número de época usado durante el benchmark (por defecto: 0).
                                   Solo aplica a algoritmos basados en DAG, excepto la familia ProgPOW.
        --benchmark-block          Número de bloque usado durante el benchmark (por defecto: 0).
                                   Solo aplica a la familia de algoritmos ProgPOW.
    -P, --protocol-dump            Registro del protocolo de usuario.
    -c, --config                   Carga un archivo de configuración en formato JSON.
    -l, --log-path                 Ruta completa del archivo de log.
        --cpu-priority             Define la prioridad del proceso (por defecto: 2): 0 inactiva, 2 normal, hasta 5 la más alta.
        --autoupdate               Actualiza automáticamente el minero cuando hay una versión más reciente disponible.
        --back-to-main-pool-sec    Obliga al minero a volver al pool principal cuando trabaja con un pool de respaldo.
                                   El parámetro se indica en segundos. (por defecto: 600)
        --exit-on-cuda-error       Obliga al minero a salir de inmediato ante un error de CUDA.
        --exit-on-connection-lost  Obliga al minero a salir de inmediato si se pierde la conexión.
        --exit-on-high-power       Obliga al minero a salir de inmediato ante un consumo elevado.
                                   (p. ej.: --exit-on-high-power 600 - sale si el consumo total supera 600W)
        --reconnect-on-fail-shares Obliga al minero a reconectarse de inmediato al pool tras N shares fallidos seguidos (por defecto: 10).
        --fork-at                  Obliga al minero a cambiar de algoritmo bajo una condición predefinida (solo funciona con el watchdog integrado activado)
                                   Condición por época: <algo_name>=epoch:<epoch_number> (p. ej.: --fork-at etchash=epoch:390).
                                   Condición por bloque: <algo_name>=block:<block_number> (p. ej.: --fork-at x16rv2=block:6526421).
                                   Condición por hora:  <algo_name>=time:<YYYY-MM-DDTHH:MM:SS>. La hora debe indicarse en UTC+0.
                                   (p. ej.: --fork-at firopow=time:2021-10-26T06:00:00).
                                   Para cambiar el puerto del pool principal, escríbelo justo después del algoritmo: <algo_name>:<port_number>
                                   (p. ej.: --fork-at x16rv2:4081=time:2019-10-01T16:00:00).

  --------------------- Ejecución de scripts personalizados ---------------
    -- (los scripts deben estar en el mismo directorio que el ejecutable de t-rex) --
    -------------------------------------------------------------------------

        --script-start             Ejecuta un script del usuario justo después de iniciar el minero (p. ej.: --script-start script_filename)
        --script-exit              Ejecuta un script del usuario justo antes de que el minero salga.
        --script-epoch-change      Ejecuta un script del usuario al cambiar de época.
        --script-crash             Ejecuta un script del usuario si el minero falla.
        --script-low-hash          Ejecuta un script del usuario si el hashrate es bajo. El umbral se indica en megahashes por segundo.
                                   Ejemplo: --script-low-hash script_to_activate:50
                                            (activa el script "script_to_activate" cuando el hashrate total baja a 50MH/s)

  -------------------- Ajuste fino de la GPU (Windows y Linux) ------------

        --pl                       Define el límite de potencia de la GPU (Windows: en porcentaje, Linux: en vatios)
                                   Requiere ejecutar el minero con privilegios de administrador.
        --lock-cclock              Fija la frecuencia del núcleo de la GPU deseada, en MHz. (por defecto: 0 - desactivado).
                                   Requiere ejecutar el minero con privilegios de administrador.
                                   Ejemplo: --lock-cclock 1000 (aplica 1000Mhz a todas las tarjetas que admiten esta función)
                                            --lock-cclock 1000,1300,0 (aplica 1000Mhz a la GPU #0, 1300MHz a la GPU #1 e ignora la GPU #2)
        --mt                       Modo de ajuste de memoria (por defecto: 0 - desactivado). Rango de 0 a 6. Como recomendación general,
                                   empieza con 1 y auméntalo solo si la GPU es estable.
                                   El efecto es similar al de ETHlargementPill.
                                   Solo compatible con GPUs Pascal con memoria GDDR5 o GDDR5X.
                                   Requiere ejecutar el minero con privilegios de administrador.
                                   Puede indicarse como lista separada por comas para aplicar valores distintos a cada tarjeta.
                                   Ejemplo: --mt 4 (aplica el modo de ajuste #4 a todas las tarjetas que admiten esta función)
                                            --mt 3,3,3,0 (aplica el modo de ajuste #3 a todas las tarjetas excepto la última)

  -------------------- Ajuste fino de la GPU (solo Windows) ---------------

                                   Todas las opciones pueden indicarse como lista separada por comas para aplicar valores
                                   distintos a cada tarjeta. (valor por defecto de todas las opciones: 0 - no se usa)
        --fan                      Define la velocidad del ventilador de la GPU en porcentaje o una temperatura objetivo (auto-fan).
                                   Formatos válidos:
                                      --fan N           (donde N es la velocidad del ventilador)
                                      --fan t:N         (donde N es la temperatura objetivo del núcleo)
                                      --fan t:N[F1-F2]  (igual que el anterior, pero con la velocidad del ventilador limitada al rango [F1%, F2%])
                                      --fan tm:N        (donde N es la temperatura objetivo de la memoria)
                                      --fan tm:N[F1-F2] (igual que el anterior, pero con la velocidad del ventilador limitada al rango [F1%, F2%])
                                   Ejemplo: --fan 45,t:67,tm:95,t:69[45-100],tm:90[50-95]
                                   que significa
                                      GPU #0: fijar la velocidad del ventilador en 45%
                                      GPU #1: mantener la temperatura del núcleo de la GPU en 67C
                                      GPU #2: mantener la temperatura de la memoria de la GPU en 95C
                                      GPU #3: mantener la temperatura del núcleo de la GPU en 69C
                                              con la velocidad del ventilador limitada al rango [45%, 100%]
                                      GPU #4: mantener la temperatura de la memoria de la GPU en 90C
                                              con la velocidad del ventilador limitada al rango [50%, 95%]
                                   Nota: en modo auto-fan, la velocidad de los ventiladores se limita por defecto al rango [0%, 100%].
        --cclock                   Define el offset de la frecuencia del núcleo de la GPU, en MHz.
                                   Requiere ejecutar el minero con privilegios de administrador.
                                   Se restablece a 0 al salir y durante la reconstrucción del DAG.
        --mclock                   Define el offset de la frecuencia de la memoria de la GPU, en MHz.
                                   Requiere ejecutar el minero con privilegios de administrador.
                                   Se restablece a 0 al salir y durante la reconstrucción del DAG.
        --cv                       Define el voltaje del núcleo de la GPU en porcentaje. Debe estar en el rango [0, 100].
                                   ¡Úsalo solo si sabes lo que haces!
                                   Requiere ejecutar el minero con privilegios de administrador.
        --lock-cv                  Fija el voltaje del núcleo de la GPU deseado, en mV. (por defecto: 0 - desactivado).
                                   Requiere ejecutar el minero con privilegios de administrador.
        --pstate                   Define el P-state de la GPU. Valores válidos: p0.
                                   Requiere ejecutar el minero con privilegios de administrador.

 -------------------------------------------------------------------------

        --version                  Muestra la información de la versión y sale.
    -h, --help                     Muestra esta ayuda y sale.

Descargar T-Rex Miner

0.26.8